@@ -1,5 +1,5 @@
 """
-This module implements the `se renumber_endnotes` command.
+This module implements the `se renumber-endnotes` command.
 """
 
 import argparse
@@ -18,22 +18,24 @@ def renumber_endnotes() -> int:
 	parser.add_argument("directories", metavar="DIRECTORY", nargs="+", help="a Standard Ebooks source directory")
 	args = parser.parse_args()
 
+	return_code = 0
+
 	for directory in args.directories:
 		try:
 			se_epub = SeEpub(directory)
 		except se.SeException as ex:
 			se.print_error(ex)
-			return ex.code
+			return_code = ex.code
 
 		try:
-			report = se_epub.generate_endnotes()  # returns a report on actions taken
+			found_endnote_count, changed_endnote_count = se_epub.generate_endnotes()
 			if args.verbose:
-				print(report)
+				print(f"Found {found_endnote_count} endnote{'s' if found_endnote_count != 1 else ''} and changed {changed_endnote_count} endnote{'s' if changed_endnote_count != 1 else ''}.")
 		except se.SeException as ex:
 			se.print_error(ex)
-			return ex.code
+			return_code = ex.code
 		except FileNotFoundError:
-			se.print_error("Couldn’t find `endnotes.xhtml`.")
-			return se.InvalidSeEbookException.code
+			se.print_error("Couldn’t find [path]endnotes.xhtml[/].")
+			return_code = se.InvalidSeEbookException.code
 
-	return 0
+	return return_code
