@@ -363,7 +363,7 @@ class SeEpub:
 			else:
 				existing_section.append(se.easy_xml.EasyXmlElement(child))
 
-	def recompose(self, output_xhtml5: bool) -> str:
+	def recompose(self, output_xhtml5: bool, extra_css_file: Path = None) -> str:
 		"""
 		Iterate over the XHTML files in this epub and "recompose" them into a single XHTML string representing this ebook.
 
@@ -378,25 +378,35 @@ class SeEpub:
 		title = self.metadata_dom.xpath("//dc:title/text()")[0]
 		language = self.metadata_dom.xpath("//dc:language/text()")[0]
 		css = ""
-		for filename in os.scandir(self.path / "src" / "epub" / "css"):
-			filepath = Path(filename)
-			if filepath.suffix == ".css":
-				with open(filepath, "r", encoding="utf-8") as file:
-					css = css + f"\n\n\n/* {filepath.name} */" + file.read()
+		namespaces: List[str] = []
+
+		css_filenames = ["core.css", "se.css", "local.css"]
+
+		if extra_css_file:
+			css_filenames.append(str(extra_css_file))
+
+		for filename in css_filenames:
+			filepath = self.path / "src" / "epub" / "css" / filename
+			with open(filepath, "r", encoding="utf-8") as file:
+				file_css = file.read()
+
+				namespaces = namespaces + regex.findall(r"@namespace.+?;", file_css)
+
+				file_css = regex.sub(r"\s*@(charset|namespace).+?;\s*", "\n", file_css).strip()
+
+				css = css + f"\n\n\n/* {filepath.name} */\n" + file_css
 
 		css = css.strip()
 
-		namespaces = set(regex.findall(r"@namespace.+?;", css))
-
-		css = regex.sub(r"\s*@(charset|namespace).+?;\s*", "\n", css).strip()
+		namespaces = list(set(namespaces))
 
 		if namespaces:
 			css = "\n" + css
 
-		for namespace in namespaces:
-			css = namespace + "\n" + css
+			for namespace in namespaces:
+				css = namespace + "\n" + css
 
-		css = "\t\t\t".join(css.splitlines(True))
+		css = "\t\t\t".join(css.splitlines(True)) + "\n"
 
 		# Remove min-height from CSS since it doesn't really apply to the single page format.
 		# It occurs at least in se.css
@@ -427,11 +437,11 @@ class SeEpub:
 				titlepage_node.lxml_element.addnext(node.lxml_element)
 
 		# Replace all <a href> links with internal links
-		for link in output_dom.xpath("//a[contains(@href, '#')]"):
+		for link in output_dom.xpath("//a[not(re:test(@href, '^https?://')) and contains(@href, '#')]"):
 			link.set_attr("href", regex.sub(r".+(#.+)$", r"\1", link.get_attr("href")))
 
 		# Replace all <a href> links to entire files
-		for link in output_dom.xpath("//a[not(contains(@href, '#'))]"):
+		for link in output_dom.xpath("//a[not(re:test(@href, '^https?://')) and not(contains(@href, '#'))]"):
 			href = link.get_attr("href")
 			href = regex.sub(r".+/([^/]+)$", r"#\1", href)
 			href = regex.sub(r"\.xhtml$", "", href)
@@ -446,7 +456,7 @@ class SeEpub:
 		output_xhtml = se.formatting.format_xhtml(output_xhtml)
 
 		# Insert our CSS. We do this after `clean` because `clean` will escape > in the CSS
-		output_xhtml = regex.sub(r"<style/>", "<style>\n\t\t\t" + css + "\t\t</style>", output_xhtml)
+		output_xhtml = regex.sub(r"<style/>", "<style><![CDATA[\n\t\t\t" + css + "\t\t]]></style>", output_xhtml)
 
 		if output_xhtml5:
 			output_xhtml = output_xhtml.replace("\t\t<meta charset=\"utf-8\"/>\n", "")
